==> enterprisemodules-wls_config-3.2.2.tar.gz: enterprisemodules-wls_config-3.2.2/lib/puppet/type/wls_setting.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

require 'yaml'

module Puppet
  Type.newtype(:wls_setting) do
    include EasyType

    DEFAULT_FILE = '/etc/wls_setting.yaml'

    desc <<-EOD
    This resource allows you to set the defaults for all other wls types.


    All wls types needs a `wls_setting` definition. This is a pointer to an WebLogic AdminServer and
    you need to create one for every WebLogic domain. When you don't provide a `wls_setting` identifier
    in the title of the weblogic type then it will use `default` as identifier.

    Here is an example on how to create the `default` settings:

        wls_setting { 'default':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7001",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
        }

    When you want to create an other domain, like for instance `domain2`. You use `wls_setting like this:

        wls_setting { 'domain2':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7011",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
          post_classpath     => '/opt/oracle/wlsdomains/domains/Wls1036/lib/aa.jar',
          extra_properties   => ['wls_server:.*'],
        }

    EOD

    to_get_raw_resources do
      resources_from_yaml
    end


    parameter :name
    property :user
    property :weblogic_home_dir
    property :weblogic_user
    property :connect_url
    property :weblogic_password
    property :post_classpath
    property :debug_module
    property :archive_path
    property :extra_properties
    property :custom_trust
    property :trust_keystore_file
    property :trust_keystore_passphrase

    def self.configuration
      @configuration
    end

    private

    def self.resources_from_yaml
      Puppet.debug '0 read_from_yaml '
      @configuration = read_from_yaml
      normalize(@configuration)
    end

    def self.config_file
      Pathname.new(DEFAULT_FILE).expand_path
    end

    def self.read_from_yaml
      if File.exist?(config_file)
        open(config_file) { |f| YAML.load(f) }
      else
        {}
      end
    end

    private

    def self.normalize(content)
      content = {} if content.nil?
      normalized_content = []
      content.each do | key, value|
        value[:name] = key
        normalized_content << with_hashified_keys(value)
      end
      normalized_content
    end

    def self.with_hashified_keys(hash)
      result = {}
      hash.each do |key, value|
        result[key.to_sym] = value
      end
      result
    end

  end
end

==> enterprisemodules-wls_config-3.7.1.tar.gz: enterprisemodules-wls_config-3.7.1/lib/puppet/type/wls_setting.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_setting) do
    include EasyType::YamlType

    config_file '/etc/wls_setting.yaml'

    desc <<-EOD
    This resource allows you to set the defaults for all other wls types.


    All wls types needs a `wls_setting` definition. This is a pointer to an WebLogic AdminServer and
    you need to create one for every WebLogic domain. When you don't provide a `wls_setting` identifier
    in the title of the weblogic type then it will use `default` as identifier.

    Here is an example on how to create the `default` settings:

        wls_setting { 'default':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7001",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
        }

    When you want to create an other domain, like for instance `domain2`. You use `wls_setting like this:

        wls_setting { 'domain2':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7011",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
          post_classpath     => '/opt/oracle/wlsdomains/domains/Wls1036/lib/aa.jar',
          extra_properties   => ['wls_server:.*'],
        }

    EOD

    parameter :name
    property :user
    property :weblogic_home_dir
    property :weblogic_user
    property :connect_url
    property :weblogic_password
    property :post_classpath
    property :debug_module
    property :archive_path
    property :extra_properties
    property :custom_trust
    property :trust_keystore_file
    property :trust_keystore_passphrase

  end
end
